import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:soliq_id/src/screens/widgets/custom_button.dart';
import 'package:soliq_id/src/screens/widgets/message_screen.dart';
import 'package:soliq_id/src/utils/assets.dart';
import 'package:soliq_id/src/utils/navigator_extension.dart';

import '../../localizations_util.dart';
import '../../soliq_id.dart';
import '../data/bloc/soliq_id_bloc.dart';
import '../data/repository/soliq_id_repository.dart';
import '../utils/color_utils.dart';
import '../utils/typography.dart';
import 'camera_screen.dart';

LocalizationType localeEnum = LocalizationType.UZ;

class FaceIdSignIn extends StatefulWidget {
  final String pinfl;
  final LocalizationType localizationType;
  final String guid;
  final Function onEvent;
  final bool onNavigate;

  const FaceIdSignIn({
    Key? key,
    required this.pinfl,
    required this.localizationType,
    required this.guid, required this.onEvent, required this.onNavigate,
  }) : super(key: key);

  @override
  State<FaceIdSignIn> createState() => _FaceIdSignInState();
}

class _FaceIdSignInState extends State<FaceIdSignIn> {
  String? res;
  String buttonTitle = '';
  final bool _isLoading = false;
  final DateTime date = DateTime.now();

  @override
  void initState() {
    super.initState();


    localeEnum = widget.localizationType;
    BlocProvider.of<SoliqIdBloc>(context).add(
      SoliqIdAccountInfoEvent(
        pinfl: int.parse(widget.pinfl),
        projectId: 0,
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    buttonTitle = getString('check');

    return Scaffold(
      backgroundColor: AppColor.appColor,
      appBar: AppBar(
        backgroundColor: AppColor.appColor,
        title: const Text(
          "Face ID",
          style: TextStyle(
            fontSize: 16,
            fontWeight: FontWeight.w500,
            color: Colors.black,
          ),
        ),
        centerTitle: true,
        elevation: 0,
      ),
      body: BlocConsumer<SoliqIdBloc, SoliqIdState>(
        listener: (context, state) async {
          if (state is SoliqIdAccountInfoSuccessState) {
            BlocProvider.of<SoliqIdBloc>(context).add(SoliqIdCreateSessionEvent(
              fio: state.response.data.fio,
              pinfl: int.parse(widget.pinfl),
              lang: "uz",
              projectId: 0,
            ));
          }
          if (state is SoliqIdCompareFaceSuccessState &&
              state.response.success == false) {
            if(widget.onNavigate == true){
              widget.onEvent.call(false);
            } else {
              final res = await Navigator.push(
                context,
                MaterialPageRoute(
                  builder: (_) =>
                      MessageScreen(
                        success: false,
                        message: state.response.message,
                      ),
                ),
              );
              widget.onEvent.call(false);
            }
          }
          if (state is SoliqIdCompareFaceSuccessState &&
              state.response.success == true) {
            if(widget.onNavigate == true){
              widget.onEvent.call(true);
            } else {
              await Navigator.push(
                context,
                MaterialPageRoute(
                  builder: (_) =>
                      MessageScreen(
                        success: true,
                        message: state.response.message,
                      ),
                ),
              );
              widget.onEvent.call(true);
            }
          }
        },
        builder: (context, state) {

          return Stack(
            children: [
              Align(
                alignment: Alignment.topCenter,
                child: Column(
                  children: [
                    const SizedBox(
                      height: 8,
                    ),
                    SizedBox(
                      width: MediaQuery.of(context).size.width / 2,
                      height: MediaQuery.of(context).size.width / 2,
                      child: Container(
                          margin: const EdgeInsets.all(18),
                          child: Image.asset(Assets.face_icon)),
                    ),
                    const SizedBox(
                      height: 24,
                    ),
                    BlocBuilder<SoliqIdBloc, SoliqIdState>(
                      buildWhen: (p,c)=> c is SoliqIdAccountInfoSuccessState,
                      builder: (context, state) {
                        if (state is SoliqIdAccountInfoSuccessState) {
                          return Text(
                            state.response.data.fio,
                            style: const TextStyle(
                              fontSize: 16,
                              fontWeight: FontWeight.w700,
                            ),
                          );
                        }
                        return const Text(
                          "",
                          style: TextStyle(
                            fontSize: 16,
                            fontWeight: FontWeight.w700,
                          ),
                        );
                      },
                    ),
                    const SizedBox(
                      height: 6,
                    ),
                    Text(
                      "${getString('pinfl')}: ${widget.pinfl}",
                      style: const TextStyle(
                        fontSize: 16,
                        fontWeight: FontWeight.w700,
                      ),
                    ),
                    const SizedBox(
                      height: 26,
                    ),
                    Container(
                      margin: const EdgeInsets.symmetric(horizontal: 28),
                      child: Text(getString('suggest_advice'),
                          textAlign: TextAlign.start,
                          style: FTypography.h1TextBold),
                    ),
                    const SizedBox(
                      height: 18,
                    ),
                    Padding(
                      padding: const EdgeInsets.symmetric(
                        horizontal: 24,
                      ),
                      child: Text(
                        getString("advice"),
                        textAlign: TextAlign.start,
                        style: FTypography.h1Text1,
                      ),
                    ),
                    const SizedBox(
                      height: 18,
                    ),
                  ],
                ),
              ),
              Positioned(
                bottom: 0,
                left: 0,
                right: 0,
                child: Container(
                  margin: const EdgeInsets.only(bottom: 25),
                  child: Column(
                    children: [
                      BlocBuilder<SoliqIdBloc, SoliqIdState>(
                        // buildWhen: (p,c)=> c is SoliqIdCreateSessionSuccessState,
                        builder: (context, state) {
                          return AppButton(
                            title: buttonTitle,
                            isLoading: _isLoading,
                            isDisabled:
                                state is! SoliqIdCreateSessionSuccessState,
                            onTap: () async {
                              if (state is SoliqIdCreateSessionSuccessState) {
                                final response =
                                    await pushWithBloc<SoliqIdBloc>(
                                        CameraScreen(
                                          session: state.response,
                                        ),
                                        SoliqIdBloc(
                                          getIt<SoliqIdRepository>(),
                                        ));

                                if (response != null) {
                                  BlocProvider.of<SoliqIdBloc>(context).add(
                                    SoliqIdCompareFaceEvent(
                                      deviceId: 'string',
                                      processId: state.response.sessionId,
                                      id: -60,
                                      asked: 7,
                                      date: response,
                                    ),
                                  );
                                }
                              }
                            },
                          );
                        },
                      ),
                    ],
                  ),
                ),
              ),
            ],
          );
        },
      ),
    );
  }
}
